/**
 * Virtual File System.
 *
 * Implemented by various different sources, including real files, library imports and definitions generated on-demand.
 */
import { SourceNode } from '@journeyapps/source-utils';
import { SourceEntry } from './SourceEntry';
export interface VFS {
    /**
     * List files that should be compiled or could be imported.
     */
    listFiles(): string[];
    /**
     * Get file info, or return null if it doesn't exist.
     *
     * @param path - full path to the file.
     */
    info(path: string): SourceEntry | null;
    /**
     * Given a source file, return all targets generated by this file that could affect
     * code intelligence.
     *
     * For each returned file, calling info(path) must have `generated: true`.
     *
     * If this is a file that is not generated, null must be returned.
     *
     * @param source Path to source file.
     */
    getTargetsFor(source: string): string[] | null;
    /**
     * Read a file with sourcemaps, or return null if it doesn't exist.
     *
     * @param path - full path to the file.
     */
    read(path: string): SourceNode | null;
}
