export function loadPackage(name: string, prefix?: string, context?: any, packageData?: any) {
  let fullName = name;
  if (prefix) {
    fullName += `/${prefix}`;
  }
  let result: Record<string, string> = {};

  for (let key of context.keys()) {
    // Sample: key = './db/indexing/JourneyIndex.d.ts`.
    if (key.startsWith('./')) {
      const fullKey = `${fullName}/${key.substring(2)}`;
      result[fullKey] = context(key).default;
    } else {
      console.warn(`Unexpected: ${name} ${prefix} ${key}`, context);
    }
  }

  if (packageData) {
    const typings = packageData.appTypings ?? packageData.typings ?? packageData.types;
    result[`${name}/package.json`] = JSON.stringify({ name, typings });
  }

  return result;
}

export function loadFile(name: string, context?: any) {
  if (context) {
    return context.default;
  } else {
    throw new Error('context is required');
  }
}

export const requireContext = null;
