// From: https://github.com/Microsoft/TypeScript/issues/2536
export const RESERVED_WORDS = [
  'break',
  'case',
  'catch',
  'class',
  'const',
  'continue',
  'debugger',
  'default',
  'delete',
  'do',
  'else',
  'enum',
  'export',
  'extends',
  'false',
  'finally',
  'for',
  'function',
  'if',
  'import',
  'in',
  'instanceof',
  'new',
  'null',
  'return',
  'super',
  'switch',
  'this',
  'throw',
  'true',
  'try',
  'typeof',
  'var',
  'void',
  'while',
  'with'
];

// These currently appear to work fine as interface names.
// Listed here for reference only
export const STRICT_RESERVED_WORDS = [
  'as',
  'implements',
  'interface',
  'let',
  'package',
  'private',
  'protected',
  'public',
  'static',
  'yield'
];

// Some of these appear to work as interface names, but we blacklist them all.
export const CONTEXTUAL_KEYWORDS = [
  'any',
  'boolean',
  'constructor',
  'declare',
  'get',
  'module',
  'require',
  'number',
  'set',
  'string',
  'symbol',
  'type',
  'from',
  'of'
];

export const TYPE_BLACKLIST: Record<string, boolean> = {};

for (let key of CONTEXTUAL_KEYWORDS) {
  TYPE_BLACKLIST[key] = true;
}

for (let key of RESERVED_WORDS) {
  TYPE_BLACKLIST[key] = true;
}

/**
 * Return true if the name is reserved in the context of a type / interface name.
 */
export function isReservedTypeName(name: string) {
  return name in TYPE_BLACKLIST;
}
